@@ -3,11 +3,11 @@ Aqua vuln-list to NVD CVE converter
 
 This module fetches the vulnerability data from aquasec vuln-list repo and stores them in NVD CVE 1.1 json format.
 """
+import os
 from datetime import datetime
 from zipfile import ZipFile
 
-import os
-import requests
+import httpx
 
 from vdb.lib import CustomNamedTemporaryFile
 from vdb.lib import config as config
@@ -84,11 +84,11 @@ class AquaSource(NvdSource):
             return self._process_zip(cached_zip)
         with CustomNamedTemporaryFile() as tf:
             try:
-                r = requests.get(url, stream=True)
-                for chunk in r.iter_content(chunk_size=download_chunk_size):
-                    tf.write(chunk)
-                tf.flush()
-                return self._process_zip(tf.name)
+                with httpx.stream("GET", url, follow_redirects=True) as r:
+                    for chunk in r.iter_bytes(chunk_size=download_chunk_size):
+                        tf.write(chunk)
+                    tf.flush()
+                    return self._process_zip(tf.name)
             except Exception:
                 return []
 
