@@ -21,7 +21,7 @@ except ImportError:
 
     ORJSON_AVAILABLE = False
 
-import requests
+import httpx
 
 from vdb.lib import config as config
 from vdb.lib.nvd import NvdSource
@@ -123,9 +123,7 @@ class GitHubSource(NvdSource):
                 config.gha_url, type
             )
         )
-        r = requests.post(
-            url=config.gha_url, json=get_query(type=type), headers=headers
-        )
+        r = httpx.post(url=config.gha_url, json=get_query(type=type), headers=headers)
         json_data = r.json()
         return self.convert(json_data)
 
