@@ -14,7 +14,7 @@ except ImportError:
 
     ORJSON_AVAILABLE = False
 
-import requests
+import httpx
 
 from vdb.lib import config as config
 from vdb.lib.nvd import NvdSource
@@ -72,14 +72,14 @@ class NpmSource(NvdSource):
 
     def fetch(self, payload):
         LOG.debug("Fetch npm advisory from {}".format(config.npm_audit_url))
-        r = requests.post(url=config.npm_audit_url, json=payload)
+        r = httpx.post(url=config.npm_audit_url, json=payload)
         json_data = r.json()
         return self.convert(json_data)
 
     def download_recent(self, local_store=True):
         """Method which downloads the recent CVE"""
         url = config.npm_advisories_url + "?perPage=100&page=1"
-        r = requests.get(url=url)
+        r = httpx.get(url=url)
         if r.ok:
             json_data = r.json()
             data = self.convert(json_data.get("objects"))
@@ -93,7 +93,7 @@ class NpmSource(NvdSource):
         data_list = []
         url = config.npm_advisories_url + "?perPage=100&page=1"
         for y in range(0, int(config.npm_pages_count)):
-            r = requests.get(url=url)
+            r = httpx.get(url=url)
             if r.ok:
                 json_data = r.json()
                 data = self.convert(json_data.get("objects"))
