@@ -11,7 +11,7 @@ except ImportError:
 
     ORJSON_AVAILABLE = False
 
-import requests
+import httpx
 
 from vdb.lib import (
     CustomNamedTemporaryFile,
@@ -79,13 +79,13 @@ class NvdSource(VulnerabilitySource):
         LOG.debug("Download NVD CVE from {}".format(url))
         with CustomNamedTemporaryFile() as tf:
             try:
-                r = requests.get(url, stream=True)
+                with httpx.stream("GET", url, follow_redirects=True) as r:
+                    for chunk in r.iter_bytes(chunk_size=download_chunk_size):
+                        tf.write(chunk)
+                    tf.flush()
             except Exception:
                 logging.warning(f"Exception while downloading NVD feed from {url}")
                 return None
-            for chunk in r.iter_content(chunk_size=download_chunk_size):
-                tf.write(chunk)
-            tf.flush()
             with gzip.open(tf.name, "rb") as gzipjf:
                 try:
                     cve_data = gzipjf.read()
