@@ -5,7 +5,7 @@ This module fetches the vulnerability data from osv.dev and stores them in NVD C
 """
 from zipfile import ZipFile
 
-import requests
+import httpx
 
 from vdb.lib import CustomNamedTemporaryFile
 from vdb.lib import config as config
@@ -57,10 +57,10 @@ class OSVSource(NvdSource):
         ret_data = []
         with CustomNamedTemporaryFile() as tf:
             try:
-                r = requests.get(url, stream=True)
-                for chunk in r.iter_content(chunk_size=download_chunk_size):
-                    tf.write(chunk)
-                tf.flush()
+                with httpx.stream("GET", url, follow_redirects=True) as r:
+                    for chunk in r.iter_bytes(chunk_size=download_chunk_size):
+                        tf.write(chunk)
+                    tf.flush()
             except Exception:
                 return ret_data
             with ZipFile(tf.name, "r") as zipfp:
